@@ -33,7 +33,7 @@ package Apache2::AMFWURFLFilterMemcached;
 
   use vars qw($VERSION);
   my $CommonLib = new Apache2::AMFCommonLib ();
-  $VERSION= "3.05";
+  $VERSION= "3.06";
   my %Capability;
   my %Array_fb;
   my %Array_id;
@@ -521,6 +521,8 @@ sub handler {
     my $variabile="";
     my $user_agent=$f->headers_in->{'User-Agent'}|| '';
     my $x_user_agent=$f->headers_in->{'X-Device-User-Agent'}|| '';
+    my $x_operamini_phone_ua=$f->headers_in->{'X-OperaMini-Phone-Ua'}|| '';
+    my $x_operamini_ua=$f->headers_in->{'X-OperaMini-Ua'}|| '';
     my $query_string=$f->args;
     my $docroot = $f->document_root();
     my $id="";
@@ -540,9 +542,13 @@ sub handler {
     
 
     if ($x_user_agent) {
-       $f->log->warn("Warn probably transcoder: $x_user_agent");
        $user_agent=$x_user_agent;
     }	  
+    if ($x_operamini_phone_ua) {
+       $user_agent=$x_operamini_phone_ua;
+    }
+    
+
 	if ($user_agent =~ m/Blackberry/i) {	 
 		$user_agent=substr($user_agent,index($user_agent,'BlackBerry'));
 		$mobile=1;
@@ -615,7 +621,13 @@ sub handler {
 	}
     
 	$f->subprocess_env("AMF_VER" => $VERSION);
-	$f->subprocess_env("AMF_WURFLVER" => $WURFLVersion);	 
+	$f->subprocess_env("AMF_WURFLVER" => $WURFLVersion);
+	if ($x_operamini_ua) {
+	    $f->subprocess_env("AMF_MOBILE_BROWSER" => $x_operamini_ua);
+	    $f->pnotes("mobile_browser" => $x_operamini_ua);
+	    $f->subprocess_env("AMF_IS_TRANCODER" => 'true');		
+	    $f->pnotes("is_transcoder" => 'true');
+	}
 	return Apache2::Const::DECLINED;
 }
 1; 
